@@ -81,8 +81,11 @@ BIGGER = '>'
 
 UNKNOWN = 'Unknown'
 
-TYPE_FUNCTION = 'function'
+TYPE_MODULE = 'module'
 TYPE_CLASS = 'class'
+TYPE_METHOD = 'method'
+TYPE_FUNCTION = 'function'
+TYPE_BUILTIN_FUNCTION_OR_METHOD = 'builtin_function_or_method'
 TYPE_BOOLEAN = 'bool'
 TYPE_STRING = 'str'
 TYPE_INTEGER = 'int'
@@ -92,6 +95,22 @@ TYPE_LIST = 'list'
 TYPE_DICT = 'dict'
 TYPE_SET = 'set'
 
+NATIVE_TYPES = [
+    TYPE_MODULE,
+    TYPE_CLASS,
+    TYPE_METHOD,
+    TYPE_FUNCTION,
+    TYPE_BUILTIN_FUNCTION_OR_METHOD,
+    TYPE_BOOLEAN,
+    TYPE_STRING,
+    TYPE_INTEGER,
+    TYPE_FLOAT,
+    TYPE_TUPLE,
+    TYPE_LIST,
+    TYPE_DICT,
+    TYPE_SET
+]
+
 NULL_VALUE = 'null'
 TRUE_VALUE = 'true'
 FALSE_VALUE = 'false'
@@ -162,8 +181,11 @@ WITH_COLOR = True
 WITHOUT_COLOR = False
 
 NATIVE_PROMPT_COLOR = {
-    TYPE_FUNCTION : BRIGHT_BLUE,
+    TYPE_MODULE : BRIGHT_BLUE,
     TYPE_CLASS : DARK_BLUE,
+    TYPE_METHOD : BRIGHT_BLUE,
+    TYPE_BUILTIN_FUNCTION_OR_METHOD : BRIGHT_BLUE,
+    TYPE_FUNCTION : BRIGHT_BLUE,
     TYPE_BOOLEAN : BRIGHT_WHITE,
     TYPE_STRING : DARK_YELLOW,
     TYPE_INTEGER : DARK_GREEN, ###- BRIGHT_BLACK, ###-
